@@ -1,24 +1,17 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-*/
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-/*
-  Copyright (C) 2008 Eli J. MacKenzie <argonel at gmail.com>
+    SPDX-FileCopyrightText: 2008 Eli J. MacKenzie <argonel at gmail.com>
 */
 
 #include "ircqueue.h"
 
+#include "server.h"
+#include "konversation_log.h"
+
 #include <QTimer>
 #include <QString>
 
-#include "server.h"
-
 IRCMessage::IRCMessage(const QString &str)
     : s(str) //, codec(QTextCodec::codecForName("utf8"))
 {
@@ -71,15 +64,15 @@ IRCQueue::IRCQueue(Server *server, EmptyingRate& rate, int ind) :
     connect(m_timer, &QTimer::timeout, this, &IRCQueue::sendNow);
     if (server)
     {
-        connect(server, SIGNAL(serverOnline(bool)), SLOT(serverOnline(bool)));
-        connect(server, SIGNAL(sentStat(int,int,IRCQueue*)), SLOT(sent(int,int,IRCQueue*)));
+        connect(server, &Server::serverOnline, this, &IRCQueue::serverOnline);
+        connect(server, &Server::sentStat, this, &IRCQueue::sent);
         m_blocked=!(m_server->isConnected());
     }
 }
 
 IRCQueue::~IRCQueue()
 {
-    qDebug();
+    qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 }
 
 QString IRCQueue::pop()
@@ -94,23 +87,23 @@ QString IRCQueue::pop()
     return msg.text();
 }
 
-int IRCQueue::nextSize()
+int IRCQueue::nextSize() const
 {
     if (m_pending.isEmpty())
         return 0;
     return m_pending.first().text().length();
 }
 
-int IRCQueue::currentWait()
+int IRCQueue::currentWait() const
 {
     if (m_pending.isEmpty())
         return 0;
     return m_pending.first().age();
 }
 
-int IRCQueue::elapsed()
+int IRCQueue::elapsed() const
 {
-    if (m_startedAt.isNull())
+    if (!m_startedAt.isValid())
         return 0;
     else
         return m_startedAt.elapsed(); //FIXME if its been more than a day since this queue was used, this breaks
@@ -180,7 +173,8 @@ void IRCQueue::reset()
     if (m_server)
         m_blocked=!(m_server->isConnected()); //FIXME  (maybe) "we can't do this anymore because blocked can't correspond to whether the server is online, instead must correspond to whether the socket has become writable (readyWrite)"
 
-    m_startedAt=m_globalLastSent=m_lastSent=QTime();
+    m_startedAt.invalidate();
+    m_globalLastSent=m_lastSent=QTime();
     m_pending.clear();
     m_linesSent=m_bytesSent=m_globalBytesSent=m_globalLinesSent=0;
 }
